@@ -1,7 +1,9 @@
+from os import path
 from .schema.builder import SchemaBuilder, Schema
 from .schema.node import SchemaNode, SchemaGenerationError
 from .schema.strategies.base import SchemaStrategy, TypedSchemaStrategy
 
+__version__ = '1.2.2'
 __all__ = [
     'SchemaBuilder',
     'SchemaNode',
